@@ -24,6 +24,8 @@
 #ifdef GRPC_CFSTREAM
 #import <CoreFoundation/CoreFoundation.h>
 
+#include "absl/log/log.h"
+
 #include <grpc/grpc.h>
 #include <grpc/support/atm.h>
 #include <grpc/support/sync.h>
@@ -35,8 +37,6 @@
 #include "src/core/lib/iomgr/ev_apple.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 
-extern grpc_core::TraceFlag grpc_tcp_trace;
-
 GrpcLibraryInitHolder::GrpcLibraryInitHolder() { grpc_init(); }
 
 GrpcLibraryInitHolder::~GrpcLibraryInitHolder() { grpc_shutdown(); }
@@ -65,9 +65,9 @@ void CFStreamHandle::ReadCallback(CFReadStreamRef stream,
   grpc_error_handle error;
   CFErrorRef stream_error;
   CFStreamHandle* handle = static_cast<CFStreamHandle*>(client_callback_info);
-  if (grpc_tcp_trace.enabled()) {
-    gpr_log(GPR_DEBUG, "CFStream ReadCallback (%p, %p, %lu, %p)", handle,
-            stream, type, client_callback_info);
+  if (GRPC_TRACE_FLAG_ENABLED(tcp)) {
+    VLOG(2) << "CFStream ReadCallback (" << handle << ", " << stream << ", "
+            << type << ", " << client_callback_info << ")";
   }
   switch (type) {
     case kCFStreamEventOpenCompleted:
@@ -99,9 +99,9 @@ void CFStreamHandle::WriteCallback(CFWriteStreamRef stream,
   grpc_error_handle error;
   CFErrorRef stream_error;
   CFStreamHandle* handle = static_cast<CFStreamHandle*>(clientCallBackInfo);
-  if (grpc_tcp_trace.enabled()) {
-    gpr_log(GPR_DEBUG, "CFStream WriteCallback (%p, %p, %lu, %p)", handle,
-            stream, type, clientCallBackInfo);
+  if (GRPC_TRACE_FLAG_ENABLED(tcp)) {
+    VLOG(2) << "CFStream WriteCallback (" << handle << ", " << stream << ", "
+            << type << ", " << clientCallBackInfo << ")";
   }
   switch (type) {
     case kCFStreamEventOpenCompleted:
@@ -176,21 +176,19 @@ void CFStreamHandle::Shutdown(grpc_error_handle error) {
 }
 
 void CFStreamHandle::Ref(const char* file, int line, const char* reason) {
-  if (grpc_tcp_trace.enabled()) {
+  if (GRPC_TRACE_FLAG_ENABLED(tcp)) {
     gpr_atm val = gpr_atm_no_barrier_load(&refcount_.count);
-    gpr_log(file, line, GPR_LOG_SEVERITY_DEBUG,
-            "CFStream Handle ref %p : %s %" PRIdPTR " -> %" PRIdPTR, this,
-            reason, val, val + 1);
+    VLOG(2).AtLocation(file, line) << "CFStream Handle ref " << this << " : "
+                                   << reason << " " << val << " -> " << val + 1;
   }
   gpr_ref(&refcount_);
 }
 
 void CFStreamHandle::Unref(const char* file, int line, const char* reason) {
-  if (grpc_tcp_trace.enabled()) {
+  if (GRPC_TRACE_FLAG_ENABLED(tcp)) {
     gpr_atm val = gpr_atm_no_barrier_load(&refcount_.count);
-    gpr_log(GPR_DEBUG,
-            "CFStream Handle unref %p : %s %" PRIdPTR " -> %" PRIdPTR, this,
-            reason, val, val - 1);
+    VLOG(2).AtLocation(file, line) << "CFStream Handle unref " << this << " : "
+                                   << reason << " " << val << " -> " << val - 1;
   }
   if (gpr_unref(&refcount_)) {
     delete this;
