@@ -12,17 +12,20 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#ifndef GRPC_CORE_LIB_PROMISE_MAP_PIPE_H
-#define GRPC_CORE_LIB_PROMISE_MAP_PIPE_H
-
-#include <grpc/support/port_platform.h>
+#ifndef GRPC_SRC_CORE_LIB_PROMISE_MAP_PIPE_H
+#define GRPC_SRC_CORE_LIB_PROMISE_MAP_PIPE_H
 
+#include "absl/log/log.h"
 #include "absl/status/status.h"
 
+#include <grpc/support/log.h>
+#include <grpc/support/port_platform.h>
+
 #include "src/core/lib/promise/detail/promise_factory.h"
 #include "src/core/lib/promise/for_each.h"
 #include "src/core/lib/promise/map.h"
 #include "src/core/lib/promise/pipe.h"
+#include "src/core/lib/promise/poll.h"
 #include "src/core/lib/promise/try_seq.h"
 
 namespace grpc_core {
@@ -40,14 +43,21 @@ auto MapPipe(PipeReceiver<T> src, PipeSender<T> dst, Filter filter_factory) {
       [filter_factory = promise_detail::RepeatedPromiseFactory<T, Filter>(
            std::move(filter_factory)),
        dst = std::move(dst)](T t) mutable {
-        return TrySeq(filter_factory.Make(std::move(t)), [&dst](T t) {
-          return Map(dst.Push(std::move(t)), [](bool successful_push) {
-            if (successful_push) {
-              return absl::OkStatus();
-            }
-            return absl::CancelledError();
-          });
-        });
+        return TrySeq(
+            [] {
+              GRPC_TRACE_VLOG(promise_primitives, 2) << "MapPipe: start map";
+              return Empty{};
+            },
+            filter_factory.Make(std::move(t)),
+            [&dst](T t) {
+              GRPC_TRACE_VLOG(promise_primitives, 2) << "MapPipe: start push";
+              return Map(dst.Push(std::move(t)), [](bool successful_push) {
+                if (successful_push) {
+                  return absl::OkStatus();
+                }
+                return absl::CancelledError();
+              });
+            });
       });
 }
 
@@ -85,4 +95,4 @@ class PipeMapper {
 
 }  // namespace grpc_core
 
-#endif  // GRPC_CORE_LIB_PROMISE_MAP_PIPE_H
+#endif  // GRPC_SRC_CORE_LIB_PROMISE_MAP_PIPE_H
