@@ -16,31 +16,30 @@
 //
 //
 
-#include <grpc/support/port_platform.h>
-
 #include <limits.h>
-#include <stdint.h>
 #include <string.h>
 
 #include <initializer_list>
 #include <memory>
 #include <string>
 
+#include "absl/log/check.h"
+#include "absl/log/log.h"
+
 #include <grpc/byte_buffer.h>
+#include <grpc/credentials.h>
 #include <grpc/grpc.h>
 #include <grpc/grpc_security.h>
 #include <grpc/impl/propagation_bits.h>
 #include <grpc/slice.h>
 #include <grpc/status.h>
-#include <grpc/support/log.h>
+#include <grpc/support/port_platform.h>
 #include <grpc/support/time.h>
 
 #include "src/core/lib/gprpp/host_port.h"
 #include "test/core/end2end/cq_verifier.h"
-#include "test/core/util/port.h"
-#include "test/core/util/test_config.h"
-
-static void* tag(intptr_t t) { return reinterpret_cast<void*>(t); }
+#include "test/core/test_util/port.h"
+#include "test/core/test_util/test_config.h"
 
 struct test_state {
   int is_client;
@@ -111,16 +110,17 @@ static void prepare_test(int is_client) {
     op->flags = GRPC_INITIAL_METADATA_WAIT_FOR_READY;
     op->reserved = nullptr;
     op++;
-    GPR_ASSERT(GRPC_CALL_OK == grpc_call_start_batch(g_state.call, g_state.ops,
-                                                     (size_t)(op - g_state.ops),
-                                                     tag(1), nullptr));
-    GPR_ASSERT(GRPC_CALL_OK ==
-               grpc_server_request_call(g_state.server, &g_state.server_call,
-                                        &g_state.call_details,
-                                        &g_state.server_initial_metadata_recv,
-                                        g_state.cq, g_state.cq, tag(101)));
-    g_state.cqv->Expect(tag(101), true);
-    g_state.cqv->Expect(tag(1), true);
+    CHECK_EQ(GRPC_CALL_OK,
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
+    CHECK_EQ(GRPC_CALL_OK,
+             grpc_server_request_call(
+                 g_state.server, &g_state.server_call, &g_state.call_details,
+                 &g_state.server_initial_metadata_recv, g_state.cq, g_state.cq,
+                 grpc_core::CqVerifier::tag(101)));
+    g_state.cqv->Expect(grpc_core::CqVerifier::tag(101), true);
+    g_state.cqv->Expect(grpc_core::CqVerifier::tag(1), true);
     g_state.cqv->Verify();
   }
 }
@@ -134,12 +134,14 @@ static void cleanup_test() {
 
   if (!g_state.is_client) {
     grpc_call_unref(g_state.server_call);
-    grpc_server_shutdown_and_notify(g_state.server, g_state.cq, tag(1000));
+    grpc_server_shutdown_and_notify(g_state.server, g_state.cq,
+                                    grpc_core::CqVerifier::tag(1000));
     grpc_event ev;
     do {
       ev = grpc_completion_queue_next(
           g_state.cq, grpc_timeout_seconds_to_deadline(5), nullptr);
-    } while (ev.type != GRPC_OP_COMPLETE || ev.tag != tag(1000));
+    } while (ev.type != GRPC_OP_COMPLETE ||
+             ev.tag != grpc_core::CqVerifier::tag(1000));
     grpc_server_destroy(g_state.server);
     grpc_call_details_destroy(&g_state.call_details);
     grpc_metadata_array_destroy(&g_state.server_initial_metadata_recv);
@@ -153,16 +155,17 @@ static void cleanup_test() {
 }
 
 static void test_non_null_reserved_on_start_batch() {
-  gpr_log(GPR_INFO, "test_non_null_reserved_on_start_batch");
+  LOG(INFO) << "test_non_null_reserved_on_start_batch";
 
   prepare_test(1);
-  GPR_ASSERT(GRPC_CALL_ERROR ==
-             grpc_call_start_batch(g_state.call, nullptr, 0, nullptr, tag(1)));
+  CHECK(GRPC_CALL_ERROR ==
+        grpc_call_start_batch(g_state.call, nullptr, 0, nullptr,
+                              grpc_core::CqVerifier::tag(1)));
   cleanup_test();
 }
 
 static void test_non_null_reserved_on_op() {
-  gpr_log(GPR_INFO, "test_non_null_reserved_on_op");
+  LOG(INFO) << "test_non_null_reserved_on_op";
 
   grpc_op* op;
   prepare_test(1);
@@ -171,17 +174,17 @@ static void test_non_null_reserved_on_op() {
   op->op = GRPC_OP_SEND_INITIAL_METADATA;
   op->data.send_initial_metadata.count = 0;
   op->flags = 0;
-  op->reserved = tag(2);
+  op->reserved = grpc_core::CqVerifier::tag(2);
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR == grpc_call_start_batch(g_state.call, g_state.ops,
+                                                 (size_t)(op - g_state.ops),
+                                                 grpc_core::CqVerifier::tag(1),
+                                                 nullptr));
   cleanup_test();
 }
 
 static void test_send_initial_metadata_more_than_once() {
-  gpr_log(GPR_INFO, "test_send_initial_metadata_more_than_once");
+  LOG(INFO) << "test_send_initial_metadata_more_than_once";
 
   grpc_op* op;
   prepare_test(1);
@@ -192,10 +195,11 @@ static void test_send_initial_metadata_more_than_once() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_OK == grpc_call_start_batch(g_state.call, g_state.ops,
-                                                   (size_t)(op - g_state.ops),
-                                                   tag(1), nullptr));
-  g_state.cqv->Expect(tag(1), false);
+  CHECK_EQ(GRPC_CALL_OK,
+           grpc_call_start_batch(g_state.call, g_state.ops,
+                                 (size_t)(op - g_state.ops),
+                                 grpc_core::CqVerifier::tag(1), nullptr));
+  g_state.cqv->Expect(grpc_core::CqVerifier::tag(1), false);
   g_state.cqv->Verify();
 
   op = g_state.ops;
@@ -204,15 +208,15 @@ static void test_send_initial_metadata_more_than_once() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
 static void test_too_many_metadata() {
-  gpr_log(GPR_INFO, "test_too_many_metadata");
+  LOG(INFO) << "test_too_many_metadata";
 
   grpc_op* op;
   prepare_test(1);
@@ -223,15 +227,15 @@ static void test_too_many_metadata() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_INVALID_METADATA ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_INVALID_METADATA ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
 static void test_send_null_message() {
-  gpr_log(GPR_INFO, "test_send_null_message");
+  LOG(INFO) << "test_send_null_message";
 
   grpc_op* op;
   prepare_test(1);
@@ -247,15 +251,15 @@ static void test_send_null_message() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_INVALID_MESSAGE ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_INVALID_MESSAGE ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
 static void test_send_messages_at_the_same_time() {
-  gpr_log(GPR_INFO, "test_send_messages_at_the_same_time");
+  LOG(INFO) << "test_send_messages_at_the_same_time";
 
   grpc_op* op;
   grpc_slice request_payload_slice =
@@ -275,20 +279,21 @@ static void test_send_messages_at_the_same_time() {
   op->reserved = nullptr;
   op++;
   op->op = GRPC_OP_SEND_MESSAGE;
-  op->data.send_message.send_message = static_cast<grpc_byte_buffer*>(tag(2));
+  op->data.send_message.send_message =
+      static_cast<grpc_byte_buffer*>(grpc_core::CqVerifier::tag(2));
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   grpc_byte_buffer_destroy(request_payload);
   cleanup_test();
 }
 
 static void test_send_server_status_from_client() {
-  gpr_log(GPR_INFO, "test_send_server_status_from_client");
+  LOG(INFO) << "test_send_server_status_from_client";
 
   grpc_op* op;
   prepare_test(1);
@@ -302,15 +307,15 @@ static void test_send_server_status_from_client() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_NOT_ON_CLIENT ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_NOT_ON_CLIENT ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
 static void test_receive_initial_metadata_twice_at_client() {
-  gpr_log(GPR_INFO, "test_receive_initial_metadata_twice_at_client");
+  LOG(INFO) << "test_receive_initial_metadata_twice_at_client";
 
   grpc_op* op;
   prepare_test(1);
@@ -321,10 +326,11 @@ static void test_receive_initial_metadata_twice_at_client() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_OK == grpc_call_start_batch(g_state.call, g_state.ops,
-                                                   (size_t)(op - g_state.ops),
-                                                   tag(1), nullptr));
-  g_state.cqv->Expect(tag(1), false);
+  CHECK_EQ(GRPC_CALL_OK,
+           grpc_call_start_batch(g_state.call, g_state.ops,
+                                 (size_t)(op - g_state.ops),
+                                 grpc_core::CqVerifier::tag(1), nullptr));
+  g_state.cqv->Expect(grpc_core::CqVerifier::tag(1), false);
   g_state.cqv->Verify();
   op = g_state.ops;
   op->op = GRPC_OP_RECV_INITIAL_METADATA;
@@ -333,15 +339,15 @@ static void test_receive_initial_metadata_twice_at_client() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
 static void test_receive_message_with_invalid_flags() {
-  gpr_log(GPR_INFO, "test_receive_message_with_invalid_flags");
+  LOG(INFO) << "test_receive_message_with_invalid_flags";
 
   grpc_op* op;
   grpc_byte_buffer* payload = nullptr;
@@ -352,15 +358,15 @@ static void test_receive_message_with_invalid_flags() {
   op->flags = 1;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_INVALID_FLAGS ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_INVALID_FLAGS ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
 static void test_receive_two_messages_at_the_same_time() {
-  gpr_log(GPR_INFO, "test_receive_two_messages_at_the_same_time");
+  LOG(INFO) << "test_receive_two_messages_at_the_same_time";
 
   grpc_op* op;
   grpc_byte_buffer* payload = nullptr;
@@ -376,15 +382,15 @@ static void test_receive_two_messages_at_the_same_time() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
 static void test_recv_close_on_server_from_client() {
-  gpr_log(GPR_INFO, "test_recv_close_on_server_from_client");
+  LOG(INFO) << "test_recv_close_on_server_from_client";
 
   grpc_op* op;
   prepare_test(1);
@@ -395,15 +401,15 @@ static void test_recv_close_on_server_from_client() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_NOT_ON_CLIENT ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_NOT_ON_CLIENT ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
 static void test_recv_status_on_client_twice() {
-  gpr_log(GPR_INFO, "test_recv_status_on_client_twice");
+  LOG(INFO) << "test_recv_status_on_client_twice";
 
   grpc_op* op;
   prepare_test(1);
@@ -417,10 +423,11 @@ static void test_recv_status_on_client_twice() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_OK == grpc_call_start_batch(g_state.call, g_state.ops,
-                                                   (size_t)(op - g_state.ops),
-                                                   tag(1), nullptr));
-  g_state.cqv->Expect(tag(1), true);
+  CHECK_EQ(GRPC_CALL_OK,
+           grpc_call_start_batch(g_state.call, g_state.ops,
+                                 (size_t)(op - g_state.ops),
+                                 grpc_core::CqVerifier::tag(1), nullptr));
+  g_state.cqv->Expect(grpc_core::CqVerifier::tag(1), true);
   g_state.cqv->Verify();
 
   op = g_state.ops;
@@ -431,15 +438,15 @@ static void test_recv_status_on_client_twice() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
 static void test_send_close_from_client_on_server() {
-  gpr_log(GPR_INFO, "test_send_close_from_client_on_server");
+  LOG(INFO) << "test_send_close_from_client_on_server";
 
   grpc_op* op;
   prepare_test(0);
@@ -449,15 +456,15 @@ static void test_send_close_from_client_on_server() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_NOT_ON_SERVER ==
-             grpc_call_start_batch(g_state.server_call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(2),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_NOT_ON_SERVER ==
+        grpc_call_start_batch(g_state.server_call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
 static void test_recv_status_on_client_from_server() {
-  gpr_log(GPR_INFO, "test_recv_status_on_client_from_server");
+  LOG(INFO) << "test_recv_status_on_client_from_server";
 
   grpc_op* op;
   prepare_test(0);
@@ -471,15 +478,15 @@ static void test_recv_status_on_client_from_server() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_NOT_ON_SERVER ==
-             grpc_call_start_batch(g_state.server_call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(2),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_NOT_ON_SERVER ==
+        grpc_call_start_batch(g_state.server_call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
 static void test_send_status_from_server_with_invalid_flags() {
-  gpr_log(GPR_INFO, "test_send_status_from_server_with_invalid_flags");
+  LOG(INFO) << "test_send_status_from_server_with_invalid_flags";
 
   grpc_op* op;
   prepare_test(0);
@@ -493,15 +500,15 @@ static void test_send_status_from_server_with_invalid_flags() {
   op->flags = 1;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_INVALID_FLAGS ==
-             grpc_call_start_batch(g_state.server_call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(2),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_INVALID_FLAGS ==
+        grpc_call_start_batch(g_state.server_call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
 static void test_too_many_trailing_metadata() {
-  gpr_log(GPR_INFO, "test_too_many_trailing_metadata");
+  LOG(INFO) << "test_too_many_trailing_metadata";
 
   grpc_op* op;
   prepare_test(0);
@@ -516,15 +523,15 @@ static void test_too_many_trailing_metadata() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_INVALID_METADATA ==
-             grpc_call_start_batch(g_state.server_call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(2),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_INVALID_METADATA ==
+        grpc_call_start_batch(g_state.server_call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
 static void test_send_server_status_twice() {
-  gpr_log(GPR_INFO, "test_send_server_status_twice");
+  LOG(INFO) << "test_send_server_status_twice";
 
   grpc_op* op;
   prepare_test(0);
@@ -545,15 +552,15 @@ static void test_send_server_status_twice() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-             grpc_call_start_batch(g_state.server_call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(2),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+        grpc_call_start_batch(g_state.server_call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
 static void test_recv_close_on_server_with_invalid_flags() {
-  gpr_log(GPR_INFO, "test_recv_close_on_server_with_invalid_flags");
+  LOG(INFO) << "test_recv_close_on_server_with_invalid_flags";
 
   grpc_op* op;
   prepare_test(0);
@@ -564,15 +571,15 @@ static void test_recv_close_on_server_with_invalid_flags() {
   op->flags = 1;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_INVALID_FLAGS ==
-             grpc_call_start_batch(g_state.server_call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(2),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_INVALID_FLAGS ==
+        grpc_call_start_batch(g_state.server_call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
 static void test_recv_close_on_server_twice() {
-  gpr_log(GPR_INFO, "test_recv_close_on_server_twice");
+  LOG(INFO) << "test_recv_close_on_server_twice";
 
   grpc_op* op;
   prepare_test(0);
@@ -588,15 +595,15 @@ static void test_recv_close_on_server_twice() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-             grpc_call_start_batch(g_state.server_call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(2),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+        grpc_call_start_batch(g_state.server_call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
 static void test_invalid_initial_metadata_reserved_key() {
-  gpr_log(GPR_INFO, "test_invalid_initial_metadata_reserved_key");
+  LOG(INFO) << "test_invalid_initial_metadata_reserved_key";
 
   grpc_metadata metadata;
   metadata.key = grpc_slice_from_static_string(":start_with_colon");
@@ -611,15 +618,15 @@ static void test_invalid_initial_metadata_reserved_key() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  GPR_ASSERT(GRPC_CALL_ERROR_INVALID_METADATA ==
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops), tag(1),
-                                   nullptr));
+  CHECK(GRPC_CALL_ERROR_INVALID_METADATA ==
+        grpc_call_start_batch(g_state.call, g_state.ops,
+                              (size_t)(op - g_state.ops),
+                              grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
 static void test_multiple_ops_in_a_single_batch() {
-  gpr_log(GPR_INFO, "test_multiple_ops_in_a_single_batch");
+  LOG(INFO) << "test_multiple_ops_in_a_single_batch";
 
   grpc_op* op;
   prepare_test(1);
@@ -634,10 +641,10 @@ static void test_multiple_ops_in_a_single_batch() {
     op++;
     op->op = which;
     op++;
-    GPR_ASSERT(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-               grpc_call_start_batch(g_state.call, g_state.ops,
-                                     (size_t)(op - g_state.ops), tag(1),
-                                     nullptr));
+    CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+          grpc_call_start_batch(g_state.call, g_state.ops,
+                                (size_t)(op - g_state.ops),
+                                grpc_core::CqVerifier::tag(1), nullptr));
   }
 
   cleanup_test();
