@@ -45,6 +45,7 @@
 #include "src/core/resolver/endpoint_addresses.h"
 #include "src/core/xds/grpc/xds_bootstrap_grpc.h"
 #include "src/core/xds/grpc/xds_endpoint.h"
+#include "src/core/xds/grpc/xds_endpoint_parser.h"
 #include "src/core/xds/grpc/xds_health_status.h"
 #include "src/core/xds/xds_client/xds_bootstrap.h"
 #include "src/core/xds/xds_client/xds_client.h"
@@ -731,6 +732,53 @@ TEST_F(XdsEndpointTest, IgnoresMultipleAddressesPerEndpointWhenNotEnabled) {
   EXPECT_EQ(resource.drop_config, nullptr);
 }
 
+TEST_F(XdsEndpointTest, EndpointHostname) {
+  ClusterLoadAssignment cla;
+  cla.set_cluster_name("foo");
+  auto* locality = cla.add_endpoints();
+  locality->mutable_load_balancing_weight()->set_value(1);
+  auto* locality_name = locality->mutable_locality();
+  locality_name->set_region("myregion");
+  locality_name->set_zone("myzone");
+  locality_name->set_sub_zone("mysubzone");
+  auto* endpoint = locality->add_lb_endpoints()->mutable_endpoint();
+  endpoint->set_hostname("server.example.com");
+  auto* socket_address = endpoint->mutable_address()->mutable_socket_address();
+  socket_address->set_address("127.0.0.1");
+  socket_address->set_port_value(443);
+  std::string serialized_resource;
+  ASSERT_TRUE(cla.SerializeToString(&serialized_resource));
+  auto* resource_type = XdsEndpointResourceType::Get();
+  auto decode_result =
+      resource_type->Decode(decode_context_, serialized_resource);
+  ASSERT_TRUE(decode_result.resource.ok()) << decode_result.resource.status();
+  ASSERT_TRUE(decode_result.name.has_value());
+  EXPECT_EQ(*decode_result.name, "foo");
+  auto& resource =
+      static_cast<const XdsEndpointResource&>(**decode_result.resource);
+  ASSERT_EQ(resource.priorities.size(), 1);
+  const auto& priority = resource.priorities[0];
+  ASSERT_EQ(priority.localities.size(), 1);
+  const auto& p = *priority.localities.begin();
+  ASSERT_EQ(p.first, p.second.name.get());
+  EXPECT_EQ(p.first->region(), "myregion");
+  EXPECT_EQ(p.first->zone(), "myzone");
+  EXPECT_EQ(p.first->sub_zone(), "mysubzone");
+  EXPECT_EQ(p.second.lb_weight, 1);
+  ASSERT_EQ(p.second.endpoints.size(), 1);
+  const auto& address = p.second.endpoints.front();
+  auto addr = grpc_sockaddr_to_string(&address.address(), /*normalize=*/false);
+  ASSERT_TRUE(addr.ok()) << addr.status();
+  EXPECT_EQ(*addr, "127.0.0.1:443");
+  EXPECT_EQ(address.args(),
+            ChannelArgs()
+                .Set(GRPC_ARG_ADDRESS_WEIGHT, 1)
+                .Set(GRPC_ARG_XDS_HEALTH_STATUS,
+                     XdsHealthStatus::HealthStatus::kUnknown)
+                .Set(GRPC_ARG_ADDRESS_NAME, "server.example.com"));
+  EXPECT_EQ(resource.drop_config, nullptr);
+}
+
 TEST_F(XdsEndpointTest, MissingEndpoint) {
   ClusterLoadAssignment cla;
   cla.set_cluster_name("foo");
